@@ -247,7 +247,7 @@ def check_variable_assignment(
     value: object, varname: str, annotation: Any, memo: TypeCheckMemo
 ) -> Any:
     if _suppression.type_checks_suppressed:
-        return
+        return value
 
     try:
         check_type_internal(value, annotation, memo)
@@ -265,36 +265,36 @@ def check_variable_assignment(
 def check_multi_variable_assignment(
     value: Any, targets: list[dict[str, Any]], memo: TypeCheckMemo
 ) -> Any:
-    if _suppression.type_checks_suppressed:
-        return
-
     if max(len(target) for target in targets) == 1:
         iterated_values = [value]
     else:
         iterated_values = list(value)
 
-    for expected_types in targets:
-        value_index = 0
-        for ann_index, (varname, expected_type) in enumerate(expected_types.items()):
-            if varname.startswith("*"):
-                varname = varname[1:]
-                keys_left = len(expected_types) - 1 - ann_index
-                next_value_index = len(iterated_values) - keys_left
-                obj: object = iterated_values[value_index:next_value_index]
-                value_index = next_value_index
-            else:
-                obj = iterated_values[value_index]
-                value_index += 1
-
-            try:
-                check_type_internal(obj, expected_type, memo)
-            except TypeCheckError as exc:
-                qualname = qualified_name(obj, add_class_prefix=True)
-                exc.append_path_element(f"value assigned to {varname} ({qualname})")
-                if memo.config.typecheck_fail_callback:
-                    memo.config.typecheck_fail_callback(exc, memo)
+    if not _suppression.type_checks_suppressed:
+        for expected_types in targets:
+            value_index = 0
+            for ann_index, (varname, expected_type) in enumerate(
+                expected_types.items()
+            ):
+                if varname.startswith("*"):
+                    varname = varname[1:]
+                    keys_left = len(expected_types) - 1 - ann_index
+                    next_value_index = len(iterated_values) - keys_left
+                    obj: object = iterated_values[value_index:next_value_index]
+                    value_index = next_value_index
                 else:
-                    raise
+                    obj = iterated_values[value_index]
+                    value_index += 1
+
+                try:
+                    check_type_internal(obj, expected_type, memo)
+                except TypeCheckError as exc:
+                    qualname = qualified_name(obj, add_class_prefix=True)
+                    exc.append_path_element(f"value assigned to {varname} ({qualname})")
+                    if memo.config.typecheck_fail_callback:
+                        memo.config.typecheck_fail_callback(exc, memo)
+                    else:
+                        raise
 
     return iterated_values[0] if len(iterated_values) == 1 else iterated_values
 
